@@ -34,6 +34,8 @@ pub use makedev::{major, makedev, minor};
 pub use types::Advice;
 #[cfg(not(any(target_os = "netbsd", target_os = "redox", target_os = "openbsd")))]
 pub use types::FallocateFlags;
+#[cfg(not(target_os = "wasi"))]
+pub use types::FlockOperation;
 #[cfg(not(any(target_os = "netbsd", target_os = "redox", target_os = "wasi")))]
 pub use types::StatFs;
 #[cfg(any(target_os = "ios", target_os = "macos"))]
